@@ -1,9 +1,12 @@
 /**
  * Окно показа контекстной помощи
+ *
+ * deprecated! - Непонятно где используется
  */
+Ext.define('Ext.m3.HelpWindow', {
+    extend: 'Ext.Window',
 
-Ext.m3.HelpWindow = Ext.extend(Ext.Window, {
-    constructor: function(baseConfig, params){
+    constructor: function(baseConfig){
         this.title = 'Справочная информация';
         this.maximized = true;
         this.maximizable = true;
