@@ -1,14 +1,15 @@
-# coding: utf-8
-from __future__ import absolute_import
-
-from .containers import *
-from .controls import *
-from .fields import *
-from .menus import *
-from .misc import *
-from .panels import *
-from .windows import *
+# -*- coding: utf-8 -*-
+"""
+Created on 13.04.2011
+"""
 
+from containers import *
+from controls import *
+from fields import *
+from menus import *
+from misc import *
+from panels import *
+from windows import *
 
 try:
     from kladr.addrfield import ExtAddrComponent
